#!/home/dd/anaconda3/bin/python

class Hubby:
    """Pornhub Object."""
    
    def __init__(self, pornhub_hash, title=None, tags=[], bits=[], drips=[]):
        
        self.hash = pornhub_hash
        self.omm = "p." + pornhub_hash
        self.url = self.build_pornhub_url()
        if title:
            self.omm += "." + title.replace(" ","_")
            self.title = title
        else:
            self.title = ""
        if tags:
            for tag in tags:
                self.omm += "." + tag
            self.tags = tags

                
        self.html = self.build_html()
        
    def build_html(self):

        if self.tags:
            html_str = '<a href="' + str(self.url) + '" title="' + " ".join(self.tags) +  '">' + str(self.title) + '</a>'
        else:
            html_str = '<a href="' + str(self.url) + '">' + str(self.title) + '</a>'

        try: 
            for item in self.bits:        
                html_str += '  [' + item.html + ']'
        except:
            pass

#        if isinstance(self, Drip):
#            html_str +=  '  ' + '(a)'

        return html_str    
    
    
    
    def extract_pornhub_hash(pornhub_url):
        """Takes Pornhub URL, returns Pornhub hash."""

        m = re.search(r'viewkey=([a-z0-9]{15})$', pornhub_url)
        result = m.group(1)

        return result

    def build_pornhub_url(self):
        """Takes Pornhub Object string, returns Pornhub video URL."""
        
        url = "https://www.pornhub.com/view_video.php?viewkey=" + self.hash

        return url
    


#!/home/dd/anaconda3/bin/python
"""Mediabyte .vtt keyword search module"""
import re, os
from datetime import datetime
from . import cnf
from . import dl2

def time_in_seconds(time_str):
    """Takes time code string, returns integer time in seconds"""
    hours = int(time_str[:2])
    minutes = int(time_str[3:5])
    seconds = int(time_str[6:])
    seconds_total = hours * 3600 + minutes * 60 + seconds
    return seconds_total

def combine(time_list, min_clip_length):
    """Takes list of time codes, combines intervals shorter than min_clip_length"""
    new_list = [time_list[0]]
    comparison = new_list[-1]
    for i in range(1, len(time_list)):
        difference_in_secs = time_in_seconds(time_list[i]) - time_in_seconds(comparison)
        if difference_in_secs >= min_clip_length:
            new_list.append(time_list[i])
        comparison = time_list[i]
    return new_list

def get_filename(yt_hash):
    """Takes YouTube hash, returns subtitle file name match"""
    files = os.listdir(cnf.srt_folder_path)
    filename = ""
    for filename_str in files:
        if yt_hash in filename_str:
            filename = filename_str        
    if filename == "":
        #raise ValueError("File not found")
        return dl2.dl_srt(yt_hash)
    
    full_filename = cnf.srt_folder_path + cnf.os_sep + filename
    return full_filename

def parse_subtitles(search_term, content, min_clip_length, text_result=False):
    """Takes subtitle file content, search_term and min_clip_length, returns list of time code strings"""
    result_list = []
    text_result_list = []
    for i, line in enumerate(content):
        m = re.findall(search_term, line)
        if m:
            time_match = re.search(r"\d\d:\d\d:\d\d\.\d\d\d", line)
            prev_match = re.search(r"\d\d:\d\d:\d\d\.\d\d\d", content[i-1])
            # use the in-line time code if found
            if time_match:
                result_list.append(time_match.group(0)[:-4])
                text_result_list.append(line.replace(time_match.group(0), ""))
            # or use time code from previous line
            elif prev_match:
                result_list.append(prev_match.group(0)[:-4])
                text_result_list.append(line)

    sorted_list = sorted(set(result_list))
    if len(sorted_list) > 1:
        final_list = combine(sorted_list, min_clip_length)
    elif len(sorted_list) == 1:
        final_list = sorted_list
    else:
        final_list = []
    if text_result:
        return final_list, text_result_list
    else:
        return final_list

def time_code_to_yt_time(time_str):
    hours = int(time_str[:2])
    minutes = int(time_str[3:5])
    seconds = int(time_str[6:])
    result_str = ""
    if hours:
        result_str += str(hours) + "h"
    if minutes:
        result_str += str(minutes) + "m"
    if seconds:
        result_str += str(seconds) + "s"
    return result_str

def build_youtube_url(yt_hash, time_code):
    url = "https://youtu.be/" + yt_hash

    full_url = url + "?t=" + str(time_in_seconds(time_code))
    return full_url

def main(search_term, yt_hash, min_interval=10):
    """Takes search term and YouTube hash, returns list of time codes of occurrences"""

    filename = get_filename(yt_hash)
    if filename:
        with open(filename, 'r') as f:
            content = f.readlines()
        result = parse_subtitles(search_term, content, min_interval)
        yt_urls = []
        for item in result:
            yt_urls.append(build_youtube_url(yt_hash, item))

        return yt_urls



import string
import random
from . import yota
from . import lib
#from .parse import omm


def bit_time_gen():
    """Returns YouTube time code format string generator."""
    while True:
        seconds_int = random.randint(0,9)
        seconds_str = str(seconds_int) + 's'
        minutes_int = random.randint(0,9)
        minutes_str = str(minutes_int) + 'm'
        hours_int = random.randint(0,9)
        hours_str = str(hours_int) + 'h'
        
        result_str = ""
        if hours_int:
            result_str += hours_str
        if minutes_int:
            result_str += minutes_str
        if seconds_int:
            result_str += seconds_str
        
        yield result_str


def bit_hash_char_gen():
    """Returns bit.ly hash format string generator."""

    letters_and_numbers = []
    for character in string.ascii_letters:
        letters_and_numbers.append(character)
    for i in range(10):
        letters_and_numbers.append(str(i))

    while True:
        result = ""
        for i in range(7):
            randInt = random.randint(0, len(letters_and_numbers)-1)
            character = letters_and_numbers[randInt]
            result += character
        yield result


def bit_title_gen():
    """Returns yota format title string generator."""

    letters_and_numbers = []
    for character in string.ascii_letters:
        letters_and_numbers.append(character)
    while True:
        title_length = random.randint(5, 16)
        result = ""
        
        randInt = random.randint(0, len(string.ascii_uppercase)-1)
        character = string.ascii_uppercase[randInt]
        result += character
        
        while len(result) < title_length:
            character_set = string.ascii_letters + string.digits + '_-#:!©™&"%&/()=?'
            randInt = random.randint(0, len(character_set) -1)
            character = character_set[randInt]
            if randInt % 4 == 0 and result != "":
                result += ' '
            result += character
        yield result


def bit_tag_gen():
    """Returns yota format tag string generator."""

    letters_and_numbers = []
    for character in string.ascii_letters:
        letters_and_numbers.append(character)
    while True:
        title_length = random.randint(3, 12)
        result = ""
        
        randInt = random.randint(0, len(string.ascii_lowercase)-1)
        character = string.ascii_lowercase[randInt]
        result += character
        
        while len(result) < title_length:
            
            character_set = string.ascii_lowercase + string.digits +  '_-+#:!&"%&/()?'                #+ _#:!©™=¤
            randInt = random.randint(0, len(character_set) -1)
            character = character_set[randInt]
            result += character
        yield result



def bit_gen():
    """Returns yota format Bit string generator."""
    
    while True:
        #myGen = yota
        my_title = next(bit_title_gen())
        #print(my_title)
        NoOfTimeCodes = random.randint(0,3)
        my_tags = []
        if NoOfTimeCodes > 0:
            my_tags.append('mp3')
        for i in range(random.randint(0,4)):
            my_tags.append(next(bit_tag_gen()))
        
        my_youtube_hash = next(bit_hash_char_gen())
        
        result = []
        result_strings = []
        
        for i in range(NoOfTimeCodes):
            my_time1 = next(bit_time_gen())
            my_time_1_int = lib.Convert._time_str(my_time1)
            result.append(my_time_1_int)
            result_strings.append(my_time1)

        if len(result_strings) == 2:
            # sort order lowest first
            if result[1] < result[0]:
                result = result_strings.reverse()

        final = 'b.' + my_youtube_hash
        # if time codes found
        if result_strings:
            final += '.' + result_strings[0]
        if my_title:
            final += '.' + my_title

        for item in my_tags:
            final += '.' + item
        if result_strings and len(result_strings) == 2:
            final += '.' + result_strings[1]

        yield final


def main(count, quiet=False, do_not_parse=False, mixtape=False):
    """ Takes count integer, returns yota Bit string list, 
        NB: expensive function, Bit object creation involved 
        which calls bitly.com to parse link."""

    myGen = bit_gen()
    result = []
    for i in range(count):
        myObjectStr = next(myGen)
        if not do_not_parse:
            try:
                myObject =  lib.Convert.omm(myObjectStr)
            except ValueError as e:
                return('Error:', myObjectStr, e)
            result.append(myObject.omm)
        else:
            result.append(myObjectStr)

    if not quiet:
        if not mixtape:
            return result
        # mixtape=True && quiet=False
        else:
            myMixtape = Mixtape( lib.Convert.omm(result[0]))
            for item in result[1:]:
                myMixtape +=  lib.Convert.omm(item)
            return myMixtape







